==> optimizely-oui-48.7.4.tgz: package/src/components/ButtonIcon/index.js <==
import PropTypes from 'prop-types';
import React from 'react';
import Icon from 'react-oui-icons';
import { FILL_COLOR_MAP } from '../../utils/accessibility';

const ButtonIcon = ({
  buttonRef,
  iconFill,
  iconName,
  isDisabled,
  onClick,
  size,
  style,
  testSection,
  title,
}) => {

  // ensure valid fillColor name (in the case that propType errors are ignored)
  const fillColor = iconFill && Object.keys(FILL_COLOR_MAP).includes(iconFill) ? FILL_COLOR_MAP[iconFill] : null;

  function handleOnClick(event) {
    if (isDisabled) {
      return;
    }
    onClick(event);
  }

  return (
    <button
      className={ `oui-button oui-button-icon oui-button-icon__${size} oui-button--${style}` }
      data-oui-component={ true }
      data-test-section={ testSection }
      disabled={ isDisabled }
      onClick={ handleOnClick }
      ref={ buttonRef }
      title={ title }
      type='button'>
      <div className="flex flex--dead-center ">
        <Icon name={ iconName } size={ size } fill={ fillColor }/>
      </div>
    </button>
  );
};

ButtonIcon.propTypes = {
  /** React ref to the underlying button component */
  buttonRef: PropTypes.oneOfType([
    PropTypes.func,
    PropTypes.shape({ current: PropTypes.instanceOf(Element) }),
  ]),
  /**
   *  Color to use for the fill of the icon
   */
  iconFill: PropTypes.oneOf(Object.keys(FILL_COLOR_MAP)),
  /**
   *  Name of the icon to use
   */
  iconName: PropTypes.string.isRequired,
  /**
   * Prevent users from interacting with the button
   */
  isDisabled: PropTypes.bool,
  /**
   *  Function to perform when the close button is clicked.
   */
  onClick: PropTypes.func.isRequired,
  /**
   *  Size of the button, medium by default
   */
  size: PropTypes.oneOf(['small', 'medium', 'large']),
  /**
   *  Various style options
   */
  style: PropTypes.oneOf([
    'highlight',
    'danger',
    'danger-outline',
    'outline',
    'plain',
    'unstyled',
  ]),
  /**
   * Hook for automated JavaScript tests
   */
  testSection: PropTypes.string,
  /**
   *  Title of the button used on hover and for screen readers
   */
  title: PropTypes.string.isRequired,
};

ButtonIcon.defaultProps = {
  iconName: 'add',
  onClick: () => {},
  size: 'medium',
  title: '',
};

export default React.memo(ButtonIcon);

==> optimizely-oui-48.8.4.tgz: package/src/components/ButtonIcon/index.js <==
import PropTypes from 'prop-types';
import React from 'react';
import Icon from 'react-oui-icons';
import { FILL_COLOR_MAP } from '../../utils/accessibility';

const ButtonIcon = ({
  buttonRef,
  iconFill,
  iconName,
  isDisabled,
  onClick,
  size,
  style,
  testSection,
  title,
}) => {

  // ensure valid fillColor name (in the case that propType errors are ignored)
  const fillColor = iconFill && Object.keys(FILL_COLOR_MAP).includes(iconFill) ? FILL_COLOR_MAP[iconFill] : null;

  function handleOnClick(event) {
    if (isDisabled) {
      return;
    }
    onClick(event);
  }

  return (
    <button
      className={ `oui-button oui-button-icon oui-button-icon__${size} oui-button--${style}` }
      data-oui-component={ true }
      data-test-section={ testSection }
      disabled={ isDisabled }
      onClick={ handleOnClick }
      ref={ buttonRef }
      title={ title }
      type='button'>
      <div className="flex flex--dead-center ">
        <Icon name={ iconName } size={ size } fill={ fillColor }/>
      </div>
    </button>
  );
};

ButtonIcon.propTypes = {
  /** React ref to the underlying button component */
  buttonRef: PropTypes.oneOfType([
    PropTypes.func,
    PropTypes.shape({ current: PropTypes.instanceOf(Element) }),
  ]),
  /**
   *  Color to use for the fill of the icon
   */
  iconFill: PropTypes.oneOf(Object.keys(FILL_COLOR_MAP)),
  /**
   *  Name of the icon to use
   */
  iconName: PropTypes.string.isRequired,
  /**
   * Prevent users from interacting with the button
   */
  isDisabled: PropTypes.bool,
  /**
   *  Function to perform when the close button is clicked.
   */
  onClick: PropTypes.func,
  /**
   *  Size of the button, medium by default
   */
  size: PropTypes.oneOf(['small', 'medium', 'large']),
  /**
   *  Various style options
   */
  style: PropTypes.oneOf([
    'highlight',
    'danger',
    'danger-outline',
    'outline',
    'plain',
    'unstyled',
  ]),
  /**
   * Hook for automated JavaScript tests
   */
  testSection: PropTypes.string,
  /**
   *  Title of the button used on hover and for screen readers
   */
  title: PropTypes.string.isRequired,
};

ButtonIcon.defaultProps = {
  iconName: 'add',
  onClick: () => {},
  size: 'medium',
  title: '',
};

export default React.memo(ButtonIcon);
